status

package
v6.0.0-beta.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package status defines the Status struct used to represent service health responses in RoadRunner. The Status type carries a Code field indicating the HTTP or service status code.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Status

type Status struct {
	Code int
}

Status consists of status code from the service

Jump to